ContextToVerifyBlock

Struct ContextToVerifyBlock 

pub struct ContextToVerifyBlock {
    pub median_weight_for_block_reward: usize,
    pub effective_median_weight: usize,
    pub top_hash: [u8; 32],
    pub median_block_timestamp: Option<u64>,
    pub chain_height: usize,
    pub current_hf: HardFork,
    pub next_difficulty: u128,
    pub already_generated_coins: u64,
}
This struct contains the data needed to verify a block, implementers MUST make sure the data in this struct is calculated correctly.

Fields

median_weight_for_block_reward: usizeeffective_median_weight: usizetop_hash: [u8; 32]

The top hash of the blockchain, aka the block hash of the previous block to the one we are verifying.

median_block_timestamp: Option<u64>

Contains the median timestamp over the last 60 blocks, if there is less than 60 blocks this should be None

chain_height: usize

The current chain height.

current_hf: HardFork

The current hard-fork.

next_difficulty: u128already_generated_coins: u64

The amount of coins already minted.